pub struct Tables<const K: u8>where
Self: Supported,{ /* private fields */ }Expand description
Collection of Chia tables
Implementations
Sourceimpl<const K: u8> Tables<K>where
Self: Supported,
impl<const K: u8> Tables<K>where
Self: Supported,
Sourcepub fn create(seed: [u8; 32], cache: &TablesCache) -> Self
pub fn create(seed: [u8; 32], cache: &TablesCache) -> Self
Create Chia proof of space tables.
There is also Self::create_parallel() that can achieve higher performance and lower
latency at the cost of lower CPU efficiency and higher memory usage.
Sourcepub fn create_proofs(seed: [u8; 32], cache: &TablesCache) -> Box<Proofs<K>>
pub fn create_proofs(seed: [u8; 32], cache: &TablesCache) -> Box<Proofs<K>>
Create proofs.
This is an optimized combination of Self::create() and Self::find_proof().
There is also Self::create_proofs_parallel() that can achieve higher performance and lower
latency at the cost of lower CPU efficiency and higher memory usage.
Sourcepub fn create_parallel(seed: [u8; 32], cache: &TablesCache) -> Self
pub fn create_parallel(seed: [u8; 32], cache: &TablesCache) -> Self
Almost the same as Self::create(), but uses parallelism internally for better
performance and lower latency at the cost of lower CPU efficiency and higher memory usage
Sourcepub fn create_proofs_parallel(
seed: [u8; 32],
cache: &TablesCache,
) -> Box<Proofs<K>>
pub fn create_proofs_parallel( seed: [u8; 32], cache: &TablesCache, ) -> Box<Proofs<K>>
Almost the same as Self::create_proofs(), but uses parallelism internally for better
performance and lower latency at the cost of lower CPU efficiency and higher memory usage
Sourcepub fn find_quality<'a>(
&'a self,
challenge: &'a [u8; 32],
) -> impl Iterator<Item = [u8; 32]> + 'a
pub fn find_quality<'a>( &'a self, challenge: &'a [u8; 32], ) -> impl Iterator<Item = [u8; 32]> + 'a
Find proof of space quality for a given challenge
Sourcepub fn find_proof_raw(
&self,
first_k_challenge_bits: u32,
) -> impl Iterator<Item = [u8; _]> + '_
pub fn find_proof_raw( &self, first_k_challenge_bits: u32, ) -> impl Iterator<Item = [u8; _]> + '_
Similar to Self::find_proof(), but takes the first k challenge bits in the least
significant bits of u32 as a challenge instead
Sourcepub fn find_proof(
&self,
first_challenge_bytes: [u8; 4],
) -> impl Iterator<Item = [u8; _]> + '_
pub fn find_proof( &self, first_challenge_bytes: [u8; 4], ) -> impl Iterator<Item = [u8; _]> + '_
Find proof of space for a given challenge